@@ -9,6 +9,8 @@ import glob
 import time
 
 
+__version__ = '0.0.4'
+
 samples_s3_folder = 'pypi_samples'
 inference_samples_s3_folder = 'pypi_toinfer'
 
@@ -42,19 +44,21 @@ class client():
                        
         
         
-    def train(self, path_to_positive_samples, path_to_negative_samples, confidence_threshold):
+    def train(self, path_to_positive_samples, path_to_negative_samples, confidence_threshold, n_pos = -1, n_neg = -1):
                
         config = utils.get_config('pypi')[0]
         event_manager_endpoint = config['event_manager_endpoint']
         aws_access_key = config['aws_access_key']
         aws_secret_key = config['aws_secret_key']
            
-        event_id = 'pypi_' + ''.join(random.choices(string.ascii_uppercase + string.digits, k=9))
-        
-        print("Creating the event... event_id = {}".format(event_id)) 
-        
+        event_id = 'PP_' + ''.join(random.choices(string.ascii_uppercase + string.digits, k=9))
+
         # Upload the positive samples into s3
-        positive_samples = glob.glob(path_to_positive_samples + "/*.jpg") + glob.glob(path_to_positive_samples + "/*.png")
+        positive_samples = glob.glob(path_to_positive_samples + "/*.jpg") + glob.glob(path_to_positive_samples + "/*.png") + glob.glob(path_to_positive_samples + "/*.JPG") + glob.glob(path_to_positive_samples + "/*.PNG") + glob.glob(path_to_positive_samples + "/*.JPEG") + glob.glob(path_to_positive_samples + "/*.bmt")
+        
+        if n_pos > 0 and n_pos < len(positive_samples):
+            positive_samples = positive_samples[:n_pos]
+                
         n_positive = 0
         for positive_sample in positive_samples:
             n_positive += 1
@@ -67,7 +71,11 @@ class client():
         print("Found {} positive samples.".format(str(n_positive)))
         
         # Upload the negative samples into s3
-        negative_samples = glob.glob(path_to_negative_samples + "/*.jpg") + glob.glob(path_to_negative_samples + "/*.png")
+        negative_samples = glob.glob(path_to_positive_samples + "/*.jpg") + glob.glob(path_to_positive_samples + "/*.png") + glob.glob(path_to_positive_samples + "/*.JPG") + glob.glob(path_to_positive_samples + "/*.PNG") + glob.glob(path_to_positive_samples + "/*.JPEG") + glob.glob(path_to_positive_samples + "/*.bmt")
+        
+        if n_neg > 0 and n_neg < len(negative_samples):
+            negative_samples = negative_samples[:n_neg]
+        
         n_negative = 0
         for negative_sample in negative_samples:
             n_negative += 1
@@ -78,8 +86,9 @@ class client():
                                aws_secret_key)
         
         print("Found {} negative samples.".format(str(n_negative)))
+        print("Creating the event... event_id = {}".format(event_id)) 
+        print("Training a model...")
         
-        print("Started model training...")
         payload = {
             "event_id": event_id,
             "camera_id": 'nil',
@@ -107,6 +116,15 @@ class client():
         aws_access_key = config['aws_access_key']
         aws_secret_key = config['aws_secret_key']
         
+        events = utils.get_event(event_id)
+        conf_threshold = 0
+        if len(events) == 0:
+            return 'The event_id is invalid.'
+        elif len(events) > 1:
+            return 'Duplicate events in DB. Please contact VisualOne.'
+        else: 
+            conf_threshold = events[0]['conf_threshold']
+            
         utils.upload_to_s3(image_file, 
                            inference_samples_s3_folder, 
                            "{}.jpg".format(event_id),
@@ -123,9 +141,7 @@ class client():
             "inference_samples_s3_bucket": 'vo-fsl-demo2',
             "inference_samples_s3_folder": inference_samples_s3_folder
         }
-        
-        print("Applying the model...")
-        
+                
         resp_json = {}
         try:
             resp = requests.post(event_predictor_endpoint, json = payload)
@@ -136,14 +152,14 @@ class client():
             return 'An error occured.'
         
         result = {}
-        result['prediction'] = resp_json['prediction']
+        result['prediction'] = True if resp_json['confidence'] > conf_threshold else False
         result['confidence'] = resp_json['confidence']
         result['event_id'] = resp_json['event_id']
         result['latency'] = resp_json['latency']
         
         return result
             
-            
+        
             
             
 
